@@ -11,8 +11,8 @@
 
 require 'samizdat'
 
-s = Session.new
-
 # todo: implement material items exchange
-s.response() {|t| t.page(_('Not Implemented'),
-_('<p>Material item exchange is not implemented yet.</p>')) }
+request do |session|
+    session.template.page(_('Not Implemented'),
+        _('<p>Material item exchange is not implemented yet.</p>'))
+end
